pub struct ScalarValue<C: Curve> { /* private fields */ }Expand description
Integer values within the range of a given Curve’s scalar modulus.
This type provides a baseline level of scalar arithmetic functionality which is always available for all curves.
serde support
When the optional serde feature of this create is enabled, [Serialize]
and [Deserialize] impls are provided for this type.
The serialization is a fixed-width big endian encoding. When used with textual formats, the binary data is encoded as hexadecimal.
Implementations
Sourceimpl<C> ScalarValue<C>where
C: Curve,
impl<C> ScalarValue<C>where
C: Curve,
Sourcepub fn new(uint: C::Uint) -> CtOption<Self>
pub fn new(uint: C::Uint) -> CtOption<Self>
Create a new scalar from Curve::Uint.
Sourcepub fn from_bytes(bytes: &FieldBytes<C>) -> CtOption<Self>
pub fn from_bytes(bytes: &FieldBytes<C>) -> CtOption<Self>
Decode ScalarValue from a serialized field element
Sourcepub fn from_slice(slice: &[u8]) -> Result<Self>
pub fn from_slice(slice: &[u8]) -> Result<Self>
Decode ScalarValue from a big endian byte slice.
Errors
- if
sliceis not sized appropriately forSelf::MODULUS. - if the decoded scalar field element overflows
Self::MODULUS.
Sourcepub fn is_zero(&self) -> Choice
pub fn is_zero(&self) -> Choice
Is this ScalarValue value equal to zero?
Sourcepub fn is_even(&self) -> Choice
pub fn is_even(&self) -> Choice
Is this ScalarValue value even?
Sourcepub fn is_odd(&self) -> Choice
pub fn is_odd(&self) -> Choice
Is this ScalarValue value odd?
Sourcepub fn to_bytes(&self) -> FieldBytes<C>
pub fn to_bytes(&self) -> FieldBytes<C>
Encode ScalarValue as a serialized field element.